@@ -3,6 +3,7 @@ import g2clib
 import struct
 import string
 import math
+import functools
 import warnings
 import operator
 from datetime import datetime
@@ -619,7 +620,8 @@ lat/lon values returned by grid method may be incorrect."""
 
     def __repr__(self):
         strings = []
-        keys = self.__dict__.keys()
+        # python 3 keys() is an iterator that can't be sorted
+        keys = list(self.__dict__.keys())
         keys.sort()
         for k in keys:
             if not k.startswith('_'):
@@ -1109,7 +1111,7 @@ def Grib2Decode(filename,gribmsg=False):
             kwargs['center_wmo_code']=wmo_code
         kwargs['grid_definition_template_number']=gdtnum[n]
         kwargs['grid_definition_template']=gdtmpl[n]
-        if gdeflist[n] != []:
+        if gdeflist[n].size > 0:
             kwargs['grid_definition_list']=gdeflist[n]
         kwargs['grid_definition_info']=gdsinfo[n]
         kwargs['discipline_code']=discipline[n]
@@ -1117,7 +1119,7 @@ def Grib2Decode(filename,gribmsg=False):
         kwargs['product_definition_template']=pdtmpl[n]
         kwargs['data_representation_template_number']=drtnum[n]
         kwargs['data_representation_template']=drtmpl[n]
-        if coordlist[n] != []:
+        if coordlist[n].size > 0:
             kwargs['extra_vertical_coordinate_info']=coordlist[n]
         kwargs['number_of_data_points_to_unpack']=ndpts[n]
         kwargs['bitmap_indicator_flag']=bitmapflag[n]
@@ -1214,12 +1216,7 @@ def _repeatlast(numfields,listin):
     return listin
 
 def _flatten(lst):
-    try:
-        flist = functools.reduce(operator.add,lst)
-    except NameError: # no reduce in python 3.
-        import functools
-        flist = functools.reduce(operator.add,lst)
-    return flist
+    return functools.reduce(operator.add,lst)
 
 
 class Grib2Encode:
