@@ -84,7 +84,7 @@ def test():
     4:Minimum temperature:K (instant):regular_gg:heightAboveGround:level 2 m:fcst time 108-120 hrs:from 200402291200
 
     as above, but using step key (issue #9)
-    >>> selected_grbs = grbs.select(level=2,typeOfLevel='heightAboveGround',step=120) 
+    >>> selected_grbs = grbs.select(level=2,typeOfLevel='heightAboveGround',step=120)
     >>> for grb in selected_grbs: grb
     3:Maximum temperature:K (instant):regular_gg:heightAboveGround:level 2 m:fcst time 108-120 hrs:from 200402291200
     4:Minimum temperature:K (instant):regular_gg:heightAboveGround:level 2 m:fcst time 108-120 hrs:from 200402291200
@@ -230,12 +230,23 @@ def test():
     >>> str(grb.packingType)
     'grid_complex_spatial_differencing'
     >>> data = grb.values
+    >>> grbs.close()
     >>> str('min/max %5.2f %5.2f' % (data.min(), data.max()))
     'min/max 295.40 308.10'
+    >>> grbs = pygrib.open('sampledata/no-radius-shapeOfEarth-7.grb2')
+    >>> for grb in grbs: print(grb)
+    1:Total precipitation:kg m-2 (accum):lambert:surface:level 0:fcst time 15-30 mins (accum):from 201804100000
+    >>> str(grb.packingType)
+    'grid_simple'
+    >>> grbs.close()
     """
 
 if __name__ == "__main__":
     import doctest
-    doctest.testmod(verbose=True)
+    failure_count, test_count = doctest.testmod(verbose=True)
     import pygrib, sys
-    sys.stdout.write('using GRIB API version %s\n' % pygrib.grib_api_version)
+    sys.stdout.write('using ECCODES library version %s\n' % pygrib.grib_api_version)
+    if failure_count==0:
+        sys.exit(0)
+    else:
+        sys.exit(1)
